The Ruby files in this directory are taken from the test suite of Mastodon.
They're not executed; they are just here for reference.
The Python tests in this directory are based on the Ruby code.

The Ruby files are copyright (C) 2016-2019 Eugen Rochko & other Mastodon contributors.
They are released under the GNU Affero General Public License, version 3.
